@@ -3,7 +3,7 @@
 #' @param surveyID A string. Unique ID for the survey you want to download.
 #' Returned as `id` by the \link[qualtRics]{all_surveys} function.
 #'
-#' @seealso See \url{https://api.qualtrics.com/docs/} for documentation on the
+#' @seealso See \url{https://api.qualtrics.com/} for documentation on the
 #' Qualtrics API.
 #' @export
 #' @examples
@@ -35,11 +35,9 @@ survey_questions <- function(surveyID) {
   assert_base_url()
   assert_api_key()
 
-  # Function-specific API stuff
-  surveys_url <- create_surveys_url(Sys.getenv("QUALTRICS_BASE_URL"))
-
-  # Add survey id
-  surveys_url <- paste0(surveys_url, surveyID)
+  # Generate URL for metadata endpoint:
+  surveys_url <- generate_url(query = "metadata",
+                              surveyID = surveyID)
 
   # SEND REQUEST TO API ----
 
